@@ -5,6 +5,7 @@
 #include "mainwindow.h"
 
 #include "playlistmanager.h"
+#include "settings.h"
 
 #include <QApplication>
 #include <QCommandLineParser>
@@ -19,6 +20,8 @@
 
 int main(int argc, char *argv[])
 {
+    QGuiApplication::setHighDpiScaleFactorRoundingPolicy(Settings::instance()->hiDpiScaleFactorBehavior());
+
     QApplication a(argc, argv);
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     a.setAttribute(Qt::ApplicationAttribute::AA_UseHighDpiPixmaps);
@@ -31,7 +34,7 @@ int main(int argc, char *argv[])
 #else
     qmDir = QT_STRINGIFY(QM_FILE_INSTALL_DIR);
 #endif
-    if (translator.load(QString("PineapplePictures_%1").arg(QLocale::system().name()), qmDir)) {
+    if (translator.load(QLocale(), QLatin1String("PineapplePictures"), QLatin1String("_"), qmDir)) {
         a.installTranslator(&translator);
     }
     a.setApplicationName("Pineapple Pictures");
