@@ -55,7 +55,11 @@ MainWindow::MainWindow(QWidget *parent)
     this->setWindowIcon(QIcon(":/icons/app-icon.svg"));
     this->setMouseTracking(true);
 
-    m_pm->setAutoLoadFilterSuffix({"*.jpg", "*.jpeg", "*.jfif", "*.png", "*.gif", "*.svg", "*.bmp", "*.webp"});
+    m_pm->setAutoLoadFilterSuffix({
+        "*.jpg", "*.jpeg", "*.jfif",
+        "*.png", "*.gif", "*.svg", "*.bmp", "*.webp",
+        "*.tif", "*.tiff"
+    });
 
     m_fadeOutAnimation = new QPropertyAnimation(this, "windowOpacity");
     m_fadeOutAnimation->setDuration(300);
@@ -158,6 +162,13 @@ MainWindow::MainWindow(QWidget *parent)
     QTimer::singleShot(0, this, [this](){
         m_am->setupShortcuts();
     });
+
+    // allow some mouse events can go through these widgets for resizing window.
+    installResizeCapture(m_closeButton);
+    installResizeCapture(m_graphicsView);
+    installResizeCapture(m_graphicsView->viewport());
+    installResizeCapture(m_gv);
+    installResizeCapture(m_gv->viewport());
 }
 
 MainWindow::~MainWindow()
@@ -317,7 +328,7 @@ void MainWindow::mousePressEvent(QMouseEvent *event)
 
 void MainWindow::mouseMoveEvent(QMouseEvent *event)
 {
-    if (event->buttons() & Qt::LeftButton && m_clickedOnWindow && !isMaximized()) {
+    if (event->buttons() & Qt::LeftButton && m_clickedOnWindow && !isMaximized() && !isFullScreen()) {
         if (!window()->windowHandle()->startSystemMove()) {
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
             move(event->globalPosition().toPoint() - m_oldMousePos);
@@ -442,6 +453,10 @@ void MainWindow::contextMenuEvent(QContextMenuEvent *event)
     protectedMode->setCheckable(true);
     protectedMode->setChecked(m_protectedMode);
 
+    QAction * avoidResetTransform = m_am->actionToggleAvoidResetTransform;
+    avoidResetTransform->setCheckable(true);
+    avoidResetTransform->setChecked(m_graphicsView->avoidResetTransform());
+
     QAction * toggleSettings = m_am->actionSettings;
     QAction * helpAction = m_am->actionHelp;
     QAction * propertiesAction = m_am->actionProperties;
@@ -470,6 +485,7 @@ void MainWindow::contextMenuEvent(QContextMenuEvent *event)
     menu->addSeparator();
     menu->addAction(stayOnTopMode);
     menu->addAction(protectedMode);
+    menu->addAction(avoidResetTransform);
     menu->addSeparator();
     menu->addAction(toggleSettings);
     menu->addAction(helpAction);
@@ -534,6 +550,11 @@ void MainWindow::toggleStayOnTop()
     show();
 }
 
+void MainWindow::toggleAvoidResetTransform()
+{
+    m_graphicsView->setAvoidResetTransform(!m_graphicsView->avoidResetTransform());
+}
+
 bool MainWindow::stayOnTop() const
 {
     return windowFlags().testFlag(Qt::WindowStaysOnTopHint);
@@ -716,6 +737,11 @@ void MainWindow::on_actionToggleProtectMode_triggered()
     toggleProtectedMode();
 }
 
+void MainWindow::on_actionToggleAvoidResetTransform_triggered()
+{
+    toggleAvoidResetTransform();
+}
+
 void MainWindow::on_actionSettings_triggered()
 {
     SettingsDialog * sd = new SettingsDialog(this);
