@@ -63,6 +63,7 @@ protected slots:
     void updateWidgetsPosition();
     void toggleProtectedMode();
     void toggleStayOnTop();
+    void toggleAvoidResetTransform();
     bool stayOnTop() const;
     bool canPaste() const;
     void quitAppAction(bool force = false);
@@ -93,6 +94,7 @@ private slots:
     void on_actionPaste_triggered();
     void on_actionToggleStayOnTop_triggered();
     void on_actionToggleProtectMode_triggered();
+    void on_actionToggleAvoidResetTransform_triggered();
     void on_actionSettings_triggered();
     void on_actionHelp_triggered();
     void on_actionProperties_triggered();
